==> openjdk-src-11.0.1.u13-2-aarch64.pkg.tar.xz: jdk.localedata/sun/util/resources/cldr/ext/CurrencyNames_uz_Cyrl.java <==
/*
 * Copyright (c) 2012, 2018, Oracle and/or its affiliates. All rights reserved.
 * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
 *
 * This code is free software; you can redistribute it and/or modify it
 * under the terms of the GNU General Public License version 2 only, as
 * published by the Free Software Foundation.  Oracle designates this
 * particular file as subject to the "Classpath" exception as provided
 * by Oracle in the LICENSE file that accompanied this code.
 *
 * This code is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
 * version 2 for more details (a copy is included in the LICENSE file that
 * accompanied this code).
 *
 * You should have received a copy of the GNU General Public License version
 * 2 along with this work; if not, write to the Free Software Foundation,
 * Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA.
 *
 * Please contact Oracle, 500 Oracle Parkway, Redwood Shores, CA 94065 USA
 * or visit www.oracle.com if you need additional information or have any
 * questions.
 */

/*
 * COPYRIGHT AND PERMISSION NOTICE
 *
 * Copyright (C) 1991-2016 Unicode, Inc. All rights reserved.
 * Distributed under the Terms of Use in 
 * http://www.unicode.org/copyright.html.
 *
 * Permission is hereby granted, free of charge, to any person obtaining
 * a copy of the Unicode data files and any associated documentation
 * (the "Data Files") or Unicode software and any associated documentation
 * (the "Software") to deal in the Data Files or Software
 * without restriction, including without limitation the rights to use,
 * copy, modify, merge, publish, distribute, and/or sell copies of
 * the Data Files or Software, and to permit persons to whom the Data Files
 * or Software are furnished to do so, provided that
 * (a) this copyright and permission notice appear with all copies 
 * of the Data Files or Software,
 * (b) this copyright and permission notice appear in associated 
 * documentation, and
 * (c) there is clear notice in each modified Data File or in the Software
 * as well as in the documentation associated with the Data File(s) or
 * Software that the data or software has been modified.
 *
 * THE DATA FILES AND SOFTWARE ARE PROVIDED "AS IS", WITHOUT WARRANTY OF
 * ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE
 * WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
 * NONINFRINGEMENT OF THIRD PARTY RIGHTS.
 * IN NO EVENT SHALL THE COPYRIGHT HOLDER OR HOLDERS INCLUDED IN THIS
 * NOTICE BE LIABLE FOR ANY CLAIM, OR ANY SPECIAL INDIRECT OR CONSEQUENTIAL
 * DAMAGES, OR ANY DAMAGES WHATSOEVER RESULTING FROM LOSS OF USE,
 * DATA OR PROFITS, WHETHER IN AN ACTION OF CONTRACT, NEGLIGENCE OR OTHER
 * TORTIOUS ACTION, ARISING OUT OF OR IN CONNECTION WITH THE USE OR
 * PERFORMANCE OF THE DATA FILES OR SOFTWARE.
 *
 * Except as contained in this notice, the name of a copyright holder
 * shall not be used in advertising or otherwise to promote the sale,
 * use or other dealings in these Data Files or Software without prior
 * written authorization of the copyright holder.
 */

package sun.util.resources.cldr.ext;

import sun.util.resources.OpenListResourceBundle;

public class CurrencyNames_uz_Cyrl extends OpenListResourceBundle {
    @Override
    protected final Object[][] getContents() {
        final Object[][] data = new Object[][] {
            { "RON", "RON" },
            { "THB", "\u0e3f" },
            { "UZS", "\u0441\u045e\u043c" },
            { "ang", "\u0413\u043e\u043b\u043b\u0430\u043d\u0434 \u0410\u043d\u0442\u0438\u043b \u0433\u0443\u043b\u044c\u0434\u0435\u043d\u0438" },
            { "ars", "\u0410\u0440\u0433\u0435\u043d\u0442\u0438\u043d\u0430 \u043f\u0435\u0441\u043e\u0441\u0438" },
            { "awg", "\u0410\u0440\u0443\u0431\u0430 \u0444\u043b\u043e\u0440\u0438\u043d\u0438" },
            { "bbd", "\u0411\u0430\u0440\u0431\u0430\u0434\u043e\u0441 \u0434\u043e\u043b\u043b\u0430\u0440\u0438" },
            { "bmd", "\u0411\u0435\u0440\u043c\u0443\u0434\u0430 \u0434\u043e\u043b\u043b\u0430\u0440\u0438" },
            { "bob", "\u0411\u043e\u043b\u0438\u0432\u0438\u044f \u0431\u043e\u043b\u0432\u0438\u0430\u043d\u0438" },
            { "brl", "\u0411\u0440\u0430\u0437\u0438\u043b \u0440\u0435\u0430\u043b\u0438" },
            { "bsd", "\u0411\u0430\u0433\u0430\u043c\u0430 \u0434\u043e\u043b\u043b\u0430\u0440\u0438" },
            { "bzd", "\u0411\u0435\u043b\u0438\u0437 \u0434\u043e\u043b\u043b\u0430\u0440\u0438" },
            { "cad", "\u041a\u0430\u043d\u0430\u0434\u0430 \u0434\u043e\u043b\u043b\u0430\u0440\u0438" },
            { "clp", "\u0427\u0438\u043b\u0438 \u043f\u0435\u0441\u043e\u0441\u0438" },
            { "cny", "\u0425\u0438\u0442\u043e\u0439 \u044e\u0430\u043d\u0438" },
            { "cop", "\u041a\u043e\u043b\u0443\u043c\u0431\u0438\u044f \u043f\u0435\u0441\u043e\u0441\u0438" },
            { "crc", "\u041a\u043e\u0441\u0442\u0430-\u0420\u0438\u043a\u0430 \u043a\u043e\u043b\u043e\u043d\u0438" },
            { "cuc", "\u041a\u0443\u0431\u0430 \u0410\u0439\u0438\u0440\u0431\u043e\u0448\u043b\u0430\u0448 \u043f\u0435\u0441\u043e\u0441\u0438" },
            { "cup", "\u041a\u0443\u0431\u0430 \u043f\u0435\u0441\u043e\u0441\u0438" },
            { "dop", "\u0414\u043e\u043c\u0438\u043d\u0438\u043a\u0430\u043d \u043f\u0435\u0441\u043e\u0441\u0438" },
            { "dzd", "\u0416\u0430\u0437\u043e\u0438\u0440 \u0434\u0438\u043d\u043e\u0440\u0438" },
            { "egp", "\u041c\u0438\u0441\u0440 \u0444\u0443\u043d\u0442\u0438" },
            { "eur", "\u0415\u0432\u0440\u043e" },
            { "fkp", "\u0424\u043e\u043b\u044c\u043a\u043b\u0435\u043d\u0434 \u043e\u0440\u043e\u043b\u0438 \u0444\u0443\u043d\u0442\u0438" },
            { "gbp", "\u0418\u043d\u0433\u043b\u0438\u0437 \u0444\u0443\u043d\u0442" },
            { "gtq", "\u0413\u0432\u0430\u0442\u0435\u043c\u0430\u043b\u0430 \u043a\u0432\u0435\u0442\u0437\u0430\u043b\u0438" },
            { "gyd", "\u0413\u0430\u044f\u043d\u0430 \u0434\u043e\u043b\u043b\u0430\u0440\u0438" },
            { "hnl", "\u0413\u043e\u043d\u0434\u0443\u0440\u0430\u0441 \u043b\u0435\u043c\u043f\u0438\u0440\u0430\u0441\u0438" },
            { "htg", "\u0413\u0430\u0438\u0442\u0438 \u0433\u0443\u0440\u0434\u0430\u0441\u0438" },
            { "inr", "\u04b2\u0438\u043d\u0434 \u0440\u0443\u043f\u0438\u044f\u0441\u0438" },
            { "jmd", "\u042f\u043c\u0430\u0439\u043a\u0430 \u0434\u043e\u043b\u043b\u0430\u0440\u0438" },
            { "jpy", "\u042f\u043f\u043e\u043d \u0439\u0435\u043d\u0430\u0441\u0438" },
            { "kyd", "\u041a\u0430\u0439\u043c\u0430\u043d \u043e\u0440\u043e\u043b\u0438 \u0414\u043e\u043b\u043b\u0430\u0440\u0438" },
            { "lyd", "\u041b\u0438\u0432\u0438\u044f \u0434\u0438\u043d\u043e\u0440\u0438" },
            { "mad", "\u041c\u0430\u0440\u043e\u043a\u0430\u0448 \u0434\u0438\u0440\u04b3\u0430\u043c\u0438" },
            { "mxn", "\u041c\u0435\u043a\u0441\u0438\u043a\u0430 \u043f\u0435\u0441\u043e\u0441\u0438" },
            { "nio", "\u041d\u0438\u043a\u0430\u0440\u0430\u0433\u0443\u0430 \u043a\u043e\u0440\u0434\u043e\u0431\u0430\u0441\u0438" },
            { "pab", "\u041f\u0430\u043d\u0430\u043c\u0430 \u0431\u0430\u043b\u044c\u0431\u043e\u0430\u0441\u0438" },
            { "pen", "\u041f\u0435\u0440\u0443 \u0441\u043e\u043b" },
            { "pyg", "\u041f\u0430\u0440\u0430\u0433\u0432\u0430\u0439 \u0433\u0443\u0430\u0440\u0430\u043d\u0438" },
            { "rub", "\u0420\u0443\u0441 \u0440\u0443\u0431\u043b\u0438" },
            { "srd", "\u0421\u0443\u0440\u0438\u043d\u0430\u043c \u0434\u043e\u043b\u043b\u0430\u0440\u0438" },
            { "ttd", "\u0422\u0440\u0438\u043d\u0438\u0434\u0430\u0434 \u0432\u0430 \u0422\u043e\u0431\u0430\u0433\u043e \u0434\u043e\u043b\u043b\u0430\u0440\u0438" },
            { "usd", "\u0410\u049a\u0428 \u0434\u043e\u043b\u043b\u0430\u0440\u0438" },
            { "uyu", "\u0423\u0440\u0443\u0433\u0432\u0430\u0439 \u043f\u0435\u0441\u043e\u0441\u0438" },
            { "uzs", "\u040e\u0437\u0431\u0435\u043a\u0438\u0441\u0442\u043e\u043d \u0441\u045e\u043c" },
            { "vef", "\u0412\u0435\u043d\u0435\u0441\u0443\u044d\u043b\u0430 \u0431\u043e\u043b\u0438\u0432\u0430\u0440\u0438" },
            { "xcd", "\u0428\u0430\u0440\u049b\u0438\u0439 \u041a\u0430\u0440\u0438\u0431 \u0434\u043e\u043b\u043b\u0430\u0440\u0438" },
        };
        return data;
    }
}

==> openjdk-src-13.0.2.u8-1-aarch64.pkg.tar.xz: jdk.localedata/sun/util/resources/cldr/ext/CurrencyNames_uz_Cyrl.java <==
/*
 * Copyright (c) 2012, 2020, Oracle and/or its affiliates. All rights reserved.
 * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
 *
 * This code is free software; you can redistribute it and/or modify it
 * under the terms of the GNU General Public License version 2 only, as
 * published by the Free Software Foundation.  Oracle designates this
 * particular file as subject to the "Classpath" exception as provided
 * by Oracle in the LICENSE file that accompanied this code.
 *
 * This code is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
 * version 2 for more details (a copy is included in the LICENSE file that
 * accompanied this code).
 *
 * You should have received a copy of the GNU General Public License version
 * 2 along with this work; if not, write to the Free Software Foundation,
 * Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA.
 *
 * Please contact Oracle, 500 Oracle Parkway, Redwood Shores, CA 94065 USA
 * or visit www.oracle.com if you need additional information or have any
 * questions.
 */

/*
 * COPYRIGHT AND PERMISSION NOTICE
 *
 * Copyright (C) 1991-2016 Unicode, Inc. All rights reserved.
 * Distributed under the Terms of Use in 
 * http://www.unicode.org/copyright.html.
 *
 * Permission is hereby granted, free of charge, to any person obtaining
 * a copy of the Unicode data files and any associated documentation
 * (the "Data Files") or Unicode software and any associated documentation
 * (the "Software") to deal in the Data Files or Software
 * without restriction, including without limitation the rights to use,
 * copy, modify, merge, publish, distribute, and/or sell copies of
 * the Data Files or Software, and to permit persons to whom the Data Files
 * or Software are furnished to do so, provided that
 * (a) this copyright and permission notice appear with all copies 
 * of the Data Files or Software,
 * (b) this copyright and permission notice appear in associated 
 * documentation, and
 * (c) there is clear notice in each modified Data File or in the Software
 * as well as in the documentation associated with the Data File(s) or
 * Software that the data or software has been modified.
 *
 * THE DATA FILES AND SOFTWARE ARE PROVIDED "AS IS", WITHOUT WARRANTY OF
 * ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE
 * WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
 * NONINFRINGEMENT OF THIRD PARTY RIGHTS.
 * IN NO EVENT SHALL THE COPYRIGHT HOLDER OR HOLDERS INCLUDED IN THIS
 * NOTICE BE LIABLE FOR ANY CLAIM, OR ANY SPECIAL INDIRECT OR CONSEQUENTIAL
 * DAMAGES, OR ANY DAMAGES WHATSOEVER RESULTING FROM LOSS OF USE,
 * DATA OR PROFITS, WHETHER IN AN ACTION OF CONTRACT, NEGLIGENCE OR OTHER
 * TORTIOUS ACTION, ARISING OUT OF OR IN CONNECTION WITH THE USE OR
 * PERFORMANCE OF THE DATA FILES OR SOFTWARE.
 *
 * Except as contained in this notice, the name of a copyright holder
 * shall not be used in advertising or otherwise to promote the sale,
 * use or other dealings in these Data Files or Software without prior
 * written authorization of the copyright holder.
 */

package sun.util.resources.cldr.ext;

import sun.util.resources.OpenListResourceBundle;

public class CurrencyNames_uz_Cyrl extends OpenListResourceBundle {
    @Override
    protected final Object[][] getContents() {
        final Object[][] data = new Object[][] {
            { "RON", "RON" },
            { "THB", "\u0e3f" },
            { "UZS", "\u0441\u045e\u043c" },
            { "ang", "\u0413\u043e\u043b\u043b\u0430\u043d\u0434 \u0410\u043d\u0442\u0438\u043b \u0433\u0443\u043b\u044c\u0434\u0435\u043d\u0438" },
            { "ars", "\u0410\u0440\u0433\u0435\u043d\u0442\u0438\u043d\u0430 \u043f\u0435\u0441\u043e\u0441\u0438" },
            { "awg", "\u0410\u0440\u0443\u0431\u0430 \u0444\u043b\u043e\u0440\u0438\u043d\u0438" },
            { "bbd", "\u0411\u0430\u0440\u0431\u0430\u0434\u043e\u0441 \u0434\u043e\u043b\u043b\u0430\u0440\u0438" },
            { "bmd", "\u0411\u0435\u0440\u043c\u0443\u0434\u0430 \u0434\u043e\u043b\u043b\u0430\u0440\u0438" },
            { "bob", "\u0411\u043e\u043b\u0438\u0432\u0438\u044f \u0431\u043e\u043b\u0432\u0438\u0430\u043d\u0438" },
            { "brl", "\u0411\u0440\u0430\u0437\u0438\u043b \u0440\u0435\u0430\u043b\u0438" },
            { "bsd", "\u0411\u0430\u0433\u0430\u043c\u0430 \u0434\u043e\u043b\u043b\u0430\u0440\u0438" },
            { "bzd", "\u0411\u0435\u043b\u0438\u0437 \u0434\u043e\u043b\u043b\u0430\u0440\u0438" },
            { "cad", "\u041a\u0430\u043d\u0430\u0434\u0430 \u0434\u043e\u043b\u043b\u0430\u0440\u0438" },
            { "clp", "\u0427\u0438\u043b\u0438 \u043f\u0435\u0441\u043e\u0441\u0438" },
            { "cny", "\u0425\u0438\u0442\u043e\u0439 \u044e\u0430\u043d\u0438" },
            { "cop", "\u041a\u043e\u043b\u0443\u043c\u0431\u0438\u044f \u043f\u0435\u0441\u043e\u0441\u0438" },
            { "crc", "\u041a\u043e\u0441\u0442\u0430-\u0420\u0438\u043a\u0430 \u043a\u043e\u043b\u043e\u043d\u0438" },
            { "cuc", "\u041a\u0443\u0431\u0430 \u0410\u0439\u0438\u0440\u0431\u043e\u0448\u043b\u0430\u0448 \u043f\u0435\u0441\u043e\u0441\u0438" },
            { "cup", "\u041a\u0443\u0431\u0430 \u043f\u0435\u0441\u043e\u0441\u0438" },
            { "dop", "\u0414\u043e\u043c\u0438\u043d\u0438\u043a\u0430\u043d \u043f\u0435\u0441\u043e\u0441\u0438" },
            { "dzd", "\u0416\u0430\u0437\u043e\u0438\u0440 \u0434\u0438\u043d\u043e\u0440\u0438" },
            { "egp", "\u041c\u0438\u0441\u0440 \u0444\u0443\u043d\u0442\u0438" },
            { "eur", "\u0415\u0432\u0440\u043e" },
            { "fkp", "\u0424\u043e\u043b\u044c\u043a\u043b\u0435\u043d\u0434 \u043e\u0440\u043e\u043b\u0438 \u0444\u0443\u043d\u0442\u0438" },
            { "gbp", "\u0418\u043d\u0433\u043b\u0438\u0437 \u0444\u0443\u043d\u0442" },
            { "gtq", "\u0413\u0432\u0430\u0442\u0435\u043c\u0430\u043b\u0430 \u043a\u0432\u0435\u0442\u0437\u0430\u043b\u0438" },
            { "gyd", "\u0413\u0430\u044f\u043d\u0430 \u0434\u043e\u043b\u043b\u0430\u0440\u0438" },
            { "hnl", "\u0413\u043e\u043d\u0434\u0443\u0440\u0430\u0441 \u043b\u0435\u043c\u043f\u0438\u0440\u0430\u0441\u0438" },
            { "htg", "\u0413\u0430\u0438\u0442\u0438 \u0433\u0443\u0440\u0434\u0430\u0441\u0438" },
            { "inr", "\u04b2\u0438\u043d\u0434 \u0440\u0443\u043f\u0438\u044f\u0441\u0438" },
            { "jmd", "\u042f\u043c\u0430\u0439\u043a\u0430 \u0434\u043e\u043b\u043b\u0430\u0440\u0438" },
            { "jpy", "\u042f\u043f\u043e\u043d \u0439\u0435\u043d\u0430\u0441\u0438" },
            { "kyd", "\u041a\u0430\u0439\u043c\u0430\u043d \u043e\u0440\u043e\u043b\u0438 \u0414\u043e\u043b\u043b\u0430\u0440\u0438" },
            { "lyd", "\u041b\u0438\u0432\u0438\u044f \u0434\u0438\u043d\u043e\u0440\u0438" },
            { "mad", "\u041c\u0430\u0440\u043e\u043a\u0430\u0448 \u0434\u0438\u0440\u04b3\u0430\u043c\u0438" },
            { "mxn", "\u041c\u0435\u043a\u0441\u0438\u043a\u0430 \u043f\u0435\u0441\u043e\u0441\u0438" },
            { "nio", "\u041d\u0438\u043a\u0430\u0440\u0430\u0433\u0443\u0430 \u043a\u043e\u0440\u0434\u043e\u0431\u0430\u0441\u0438" },
            { "pab", "\u041f\u0430\u043d\u0430\u043c\u0430 \u0431\u0430\u043b\u044c\u0431\u043e\u0430\u0441\u0438" },
            { "pen", "\u041f\u0435\u0440\u0443 \u0441\u043e\u043b" },
            { "pyg", "\u041f\u0430\u0440\u0430\u0433\u0432\u0430\u0439 \u0433\u0443\u0430\u0440\u0430\u043d\u0438" },
            { "rub", "\u0420\u0443\u0441 \u0440\u0443\u0431\u043b\u0438" },
            { "srd", "\u0421\u0443\u0440\u0438\u043d\u0430\u043c \u0434\u043e\u043b\u043b\u0430\u0440\u0438" },
            { "ttd", "\u0422\u0440\u0438\u043d\u0438\u0434\u0430\u0434 \u0432\u0430 \u0422\u043e\u0431\u0430\u0433\u043e \u0434\u043e\u043b\u043b\u0430\u0440\u0438" },
            { "usd", "\u0410\u049a\u0428 \u0434\u043e\u043b\u043b\u0430\u0440\u0438" },
            { "uyu", "\u0423\u0440\u0443\u0433\u0432\u0430\u0439 \u043f\u0435\u0441\u043e\u0441\u0438" },
            { "uzs", "\u040e\u0437\u0431\u0435\u043a\u0438\u0441\u0442\u043e\u043d \u0441\u045e\u043c" },
            { "vef", "\u0412\u0435\u043d\u0435\u0441\u0443\u044d\u043b\u0430 \u0431\u043e\u043b\u0438\u0432\u0430\u0440\u0438 (2008\u20132018)" },
            { "ves", "\u0412\u0435\u043d\u0435\u0441\u0443\u044d\u043b\u0430 \u0431\u043e\u043b\u0438\u0432\u0430\u0440\u0438" },
            { "xcd", "\u0428\u0430\u0440\u049b\u0438\u0439 \u041a\u0430\u0440\u0438\u0431 \u0434\u043e\u043b\u043b\u0430\u0440\u0438" },
        };
        return data;
    }
}
